import React from 'react';
import { TransTitle, Trans, beautifyKey, extractValue, memo, sortScalarList } from '@ui-schema/ui-schema';
import { List, Map } from 'immutable';
import { useUID } from 'react-uid';
import { ValidityHelperText } from '../../Component/LocaleHelperText/LocaleHelperText';

const CheckInput = ({
  checked,
  onChange,
  label,
  value,
  classForm,
  classLabel,
  classFormControl
}) => {
  const uid = useUID();
  return /*#__PURE__*/React.createElement("div", {
    className: classForm
  }, /*#__PURE__*/React.createElement("input", {
    id: 'uis-' + uid,
    type: "checkbox",
    className: classFormControl,
    value: value,
    checked: checked,
    onChange: onChange
  }), /*#__PURE__*/React.createElement("label", {
    className: classLabel,
    htmlFor: 'uis-' + uid
  }, label));
};

const checkActive = (list, name) => list && list.contains && typeof list.contains(name) !== 'undefined' ? list.contains(name) : false;

const OptionsCheckValue = extractValue(memo(({
  oneOfValues,
  storeKeys,
  value,
  onChange,
  classLabel,
  classFormControl,
  classForm,
  schema,
  required
}) => oneOfValues ? oneOfValues.map(oneOfSchema => {
  const oneOfVal = oneOfSchema.get('const');
  const isActive = checkActive(value, oneOfVal);
  return /*#__PURE__*/React.createElement(CheckInput, {
    key: oneOfVal,
    checked: isActive,
    classForm: classForm,
    classLabel: classLabel,
    classFormControl: classFormControl,
    currentValue: isActive,
    onChange: () => {
      onChange({
        storeKeys,
        scopes: ['value'],
        type: 'update',
        updater: ({
          value: val = List()
        }) => ({
          value: sortScalarList(checkActive(val, oneOfVal) ? val.delete(val.indexOf(oneOfVal)) : val.push(oneOfVal))
        }),
        schema,
        required
      });
    },
    label: /*#__PURE__*/React.createElement(Trans, {
      schema: oneOfSchema.get('t'),
      text: oneOfSchema.get('title') || oneOfSchema.get('const'),
      context: Map({
        'relative': List(['title'])
      }),
      fallback: oneOfSchema.get('title') || beautifyKey(oneOfSchema.get('const'), oneOfSchema.get('tt'))
    })
  });
}).valueSeq() : null));

const OptionsCheck = ({
  schema,
  storeKeys,
  showValidity,
  errors,
  ownKey,
  required
}) => {
  const oneOfVal = schema.getIn(['items', 'oneOf']);
  if (!oneOfVal) return null;
  let classForm = ['custom-control', 'custom-checkbox'];
  let classLabel = ['custom-control-label', 'text-light'];
  let classFormControl = ['custom-control-input', 'checkbox-inline'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classForm.push('was-validated');
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  }), /*#__PURE__*/React.createElement(OptionsCheckValue, {
    required: required,
    type: schema.get('type'),
    classForm: classForm.join(' '),
    classLabel: classLabel.join(' '),
    classFormControl: classFormControl.join(' '),
    oneOfValues: oneOfVal,
    storeKeys: storeKeys,
    schema: schema
  }), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

export { OptionsCheck };